@@ -164,7 +164,7 @@ class DataApi(E8Api):
                 hasTm = [item['_tm'] - item['_tm'] % 86400 + 57600 for item in data]
             else:
                 intervalTm = 3600
-                if 'half_hour' in params and params['half_hour'] == 1:
+                if 'half_hour' in params and int(params['half_hour']) == 1:
                     intervalTm = 1800
                 # 完整的tm
                 fullTm = [tm for tm in range(beg_tm,end_tm,intervalTm)]
@@ -239,6 +239,8 @@ class DataApi(E8Api):
             # 数据合并
             for mid in devs:
                 if mid in self._link_info and 'wg' in self._link_info[mid]:
+                    # 记录列表数据的时间，去重复
+                    dMap = {}
                     for item in self._link_info[mid]['wg']:
                         if item['mid'] in apiData:
                             if isinstance(apiData[item['mid']],dict):
@@ -253,7 +255,24 @@ class DataApi(E8Api):
                             else:
                                 if mid not in ret:
                                     ret[mid] = []
-                                ret[mid].extend(apiData[item['mid']])
+                                period = 60
+                                # 排除重复时间，重复时间取电度较小的那个
+                                if method in ['get_daily_by_month','get_daily_in_range']:
+                                    period = 86400
+                                elif method in ['get_hourly_by_day','get_hourly_by_month','get_hourly_in_range','get_ep_by_day','get_ep_by_month','get_ep_in_range']:
+                                    period = 3600
+                                    if 'half_hour' in kwargs and int(kwargs['half_hour']) == 1:
+                                        period = 1800
+                                for d in apiData[item['mid']]:
+                                    t = (d['_tm'] - 28800) // period
+                                    if t in dMap:
+                                        if 'ImpEp' in d and 'ImpEp' in dMap[t] and d['ImpEp'] < dMap[t]['ImpEp']:
+                                            dMap[t] = d
+                                        elif 'EPt' in d and 'EPt' in dMap[t] and d['EPt'] < dMap[t]['EPt']:
+                                            dMap[t] = d
+                                    else:
+                                        dMap[t] = d
+                                ret[mid] = dMap.values()
                 else:
                     ret[mid] = apiData.get(mid,None)
             # 数据补缺
@@ -399,7 +418,8 @@ class DataApi(E8Api):
                 item['function'] = func
                 item['type'] = 3
                 # 暂时固定设置1小时内的数据
-                item['period'] = 3720
+                if 'period' not in item:
+                    item['period'] = 3720
             monitorMap[mid] = mMap
         # 组装需要设置的主动监控
         monitorPipes = {}
